Documentation
¶
Index ¶
- Constants
- func AACircleColor(renderer *sdl.Renderer, x, y, rad int, color sdl.Color) bool
- func AACircleRGBA(renderer *sdl.Renderer, x, y, rad int, r, g, b, a uint8) bool
- func AAEllipseColor(renderer *sdl.Renderer, x, y, rx, ry int, color sdl.Color) bool
- func AAEllipseRGBA(renderer *sdl.Renderer, x, y, rx, ry int, r, g, b, a uint8) bool
- func AALineColor(renderer *sdl.Renderer, x1, y1, x2, y2 int, color sdl.Color) bool
- func AALineRGBA(renderer *sdl.Renderer, x1, y1, x2, y2 int, r, g, b, a uint8) bool
- func AAPolygonColor(renderer *sdl.Renderer, vx, vy []int16, color sdl.Color) bool
- func AAPolygonRGBA(renderer *sdl.Renderer, vx, vy []int16, r, g, b, a uint8) bool
- func ArcColor(renderer *sdl.Renderer, x, y, rad, start, end int, color sdl.Color) bool
- func ArcRGBA(renderer *sdl.Renderer, x, y, rad, start, end int, r, g, b, a uint8) bool
- func BezierColor(renderer *sdl.Renderer, vx, vy []int16, s int, color sdl.Color) bool
- func BezierRGBA(renderer *sdl.Renderer, vx, vy []int16, s int, r, g, b, a uint8) bool
- func BoxColor(renderer *sdl.Renderer, x1, y1, x2, y2 int, color sdl.Color) bool
- func BoxRGBA(renderer *sdl.Renderer, x1, y1, x2, y2 int, r, g, b, a uint8) bool
- func CharacterColor(renderer *sdl.Renderer, x, y int, c byte, color sdl.Color) bool
- func CharacterRGBA(renderer *sdl.Renderer, x, y int, c, r, g, b, a uint8) bool
- func CircleColor(renderer *sdl.Renderer, x, y, rad int, color sdl.Color) bool
- func CircleRGBA(renderer *sdl.Renderer, x, y, rad int, r, g, b, a uint8) bool
- func EllipseColor(renderer *sdl.Renderer, x, y, rx, ry int, color sdl.Color) bool
- func EllipseRGBA(renderer *sdl.Renderer, x, y, rx, ry int, r, g, b, a uint8) bool
- func FilledCircleColor(renderer *sdl.Renderer, x, y, rad int, color sdl.Color) bool
- func FilledCircleRGBA(renderer *sdl.Renderer, x, y, rad int, r, g, b, a uint8) bool
- func FilledEllipseColor(renderer *sdl.Renderer, x, y, rx, ry int, color sdl.Color) bool
- func FilledEllipseRGBA(renderer *sdl.Renderer, x, y, rx, ry int, r, g, b, a uint8) bool
- func FilledPieColor(renderer *sdl.Renderer, x, y, rad, start, end int, color sdl.Color) bool
- func FilledPieRGBA(renderer *sdl.Renderer, x, y, rad, start, end int, r, g, b, a uint8) bool
- func FilledPolygonColor(renderer *sdl.Renderer, vx, vy []int16, color sdl.Color) bool
- func FilledPolygonRGBA(renderer *sdl.Renderer, vx, vy []int16, r, g, b, a uint8) bool
- func FilledTrigonColor(renderer *sdl.Renderer, x1, y1, x2, y2, x3, y3 int, color sdl.Color) bool
- func FilledTrigonRGBA(renderer *sdl.Renderer, x1, y1, x2, y2, x3, y3 int, r, g, b, a uint8) bool
- func FramerateDelay(manager *FPSmanager) uint32
- func GFXPrimitiveSetFont(fontdata []byte, cw, ch uint32)
- func GFXPrimitivesSetFontRotation(rotation uint32)
- func GetFramecount(manager *FPSmanager) (int, bool)
- func GetFramerate(manager *FPSmanager) (int, bool)
- func HlineColor(renderer *sdl.Renderer, x1, x2, y int, color sdl.Color) bool
- func HlineRGBA(renderer *sdl.Renderer, x1, x2, y int, r, g, b, a uint8) bool
- func ImageFilterAbsDiff(src1, src2, dest []byte) bool
- func ImageFilterAdd(src1, src2, dest []byte) bool
- func ImageFilterAddByte(src1, dest []byte, c byte) bool
- func ImageFilterAddUint(src1, dest []byte, c uint) bool
- func ImageFilterBinarizeUsingThreshold(src1, dest []byte, t byte) bool
- func ImageFilterBitAnd(src1, src2, dest []byte) bool
- func ImageFilterBitNegation(src1, dest []byte) bool
- func ImageFilterBitOr(src1, src2, dest []byte) bool
- func ImageFilterClipToRange(src1, dest []byte, tmin, tmax byte) bool
- func ImageFilterDiv(src1, src2, dest []byte) bool
- func ImageFilterMMXdetect() bool
- func ImageFilterMMXoff()
- func ImageFilterMMXon()
- func ImageFilterMean(src1, src2, dest []byte) bool
- func ImageFilterMult(src1, src2, dest []byte) bool
- func ImageFilterMultByByte(src1, dest []byte, c byte) bool
- func ImageFilterMultDivby2(src1, src2, dest []byte) bool
- func ImageFilterMultDivby4(src1, src2, dest []byte) bool
- func ImageFilterMultNor(src1, src2, dest []byte) bool
- func ImageFilterNormalizeLinear(src1, dest []byte, cmin, cmax, nmin, nmax int) bool
- func ImageFilterShiftLeft(src1, dest []byte, n byte) bool
- func ImageFilterShiftLeftByte(src1, dest []byte, n byte) bool
- func ImageFilterShiftLeftUint(src1, dest []byte, n byte) bool
- func ImageFilterShiftRight(src1, dest []byte, n byte) bool
- func ImageFilterShiftRightAndMultByByte(src1, dest []byte, n, c byte) bool
- func ImageFilterShiftRightUint(src1, dest []byte, n byte) bool
- func ImageFilterSub(src1, src2, dest []byte) bool
- func ImageFilterSubByte(src1, dest []byte, c byte) bool
- func ImageFilterSubUint(src1, dest []byte, c uint) bool
- func InitFramerate(manager *FPSmanager)
- func LineColor(renderer *sdl.Renderer, x1, y1, x2, y2 int, color sdl.Color) bool
- func LineRGBA(renderer *sdl.Renderer, x1, y1, x2, y2 int, r, g, b, a uint8) bool
- func PieColor(renderer *sdl.Renderer, x, y, rad, start, end int, color sdl.Color) bool
- func PieRGBA(renderer *sdl.Renderer, x, y, rad, start, end int, r, g, b, a uint8) bool
- func PixelColor(renderer *sdl.Renderer, x, y int, color sdl.Color) bool
- func PixelRGBA(renderer *sdl.Renderer, x, y int, r, g, b, a uint8) bool
- func PolygonColor(renderer *sdl.Renderer, vx, vy []int16, color sdl.Color) bool
- func PolygonRGBA(renderer *sdl.Renderer, vx, vy []int16, r, g, b, a uint8) bool
- func RectangleColor(renderer *sdl.Renderer, x1, y1, x2, y2 int, color sdl.Color) bool
- func RectangleRGBA(renderer *sdl.Renderer, x1, y1, x2, y2 int, r, g, b, a uint8) bool
- func RotateSurface90Degrees(src *sdl.Surface, numClockwiseTurns int) *sdl.Surface
- func RotoZoomSurface(src *sdl.Surface, angle, zoom float64, smooth int) *sdl.Surface
- func RotoZoomSurfaceXY(src *sdl.Surface, angle, zoomx, zoomy float64, smooth int) *sdl.Surface
- func RoundedBoxColor(renderer *sdl.Renderer, x1, y1, x2, y2, rad int, color sdl.Color) bool
- func RoundedBoxRGBA(renderer *sdl.Renderer, x1, y1, x2, y2, rad int, r, g, b, a uint8) bool
- func RoundedRectangleColor(renderer *sdl.Renderer, x1, y1, x2, y2, rad int, color sdl.Color) bool
- func RoundedRectangleRGBA(renderer *sdl.Renderer, x1, y1, x2, y2, rad int, r, g, b, a uint8) bool
- func SetFramerate(manager *FPSmanager, rate uint32) bool
- func ShrinkSurface(src *sdl.Surface, factorx, factory int) *sdl.Surface
- func StringColor(renderer *sdl.Renderer, x, y int, s string, color sdl.Color) bool
- func StringRGBA(renderer *sdl.Renderer, x, y int, s string, r, g, b, a uint8) bool
- func TexturedPolygon(renderer *sdl.Renderer, vx, vy []int16, surface *sdl.Surface, ...) bool
- func ThickLineColor(renderer *sdl.Renderer, x1, y1, x2, y2, width int, color sdl.Color) bool
- func ThickLineRGBA(renderer *sdl.Renderer, x1, y1, x2, y2, width int, r, g, b, a uint8) bool
- func TrigonColor(renderer *sdl.Renderer, x1, y1, x2, y2, x3, y3 int, color sdl.Color) bool
- func TrigonRGBA(renderer *sdl.Renderer, x1, y1, x2, y2, x3, y3 int, r, g, b, a uint8) bool
- func VlineColor(renderer *sdl.Renderer, x, y1, y2 int, color sdl.Color) bool
- func VlineRGBA(renderer *sdl.Renderer, x, y1, y2 int, r, g, b, a uint8) bool
- func ZoomSurface(src *sdl.Surface, zoomx, zoomy float64, smooth int) *sdl.Surface
- func ZoomSurfaceSize(width, height int, zoomx, zoomy float64) (dstwidth int, dstheight int)
- type FPSmanager
Constants ¶
const ( FPS_UPPER_LIMIT = 200 FPS_LOWER_LIMIT = 200 FPS_DEFAULT = 30 )
FPS
const ( SMOOTHING_OFF = 0 SMOOTHING_ON = 0 )
Variables ¶
This section is empty.
Functions ¶
func AACircleColor ¶
func AAEllipseColor ¶
func AAEllipseRGBA ¶
func AALineColor ¶
func AALineRGBA ¶
func AAPolygonColor ¶
func AAPolygonRGBA ¶
func BezierColor ¶
func BezierRGBA ¶
func CharacterColor ¶
func EllipseColor ¶
func EllipseRGBA ¶
func FilledCircleColor ¶
func FilledCircleRGBA ¶
func FilledEllipseColor ¶
func FilledEllipseRGBA ¶
func FilledPieColor ¶
func FilledPieRGBA ¶
func FilledPolygonColor ¶
func FilledPolygonRGBA ¶
func FilledTrigonColor ¶
func FilledTrigonRGBA ¶
func FramerateDelay ¶
func FramerateDelay(manager *FPSmanager) uint32
func GFXPrimitiveSetFont ¶
func GFXPrimitivesSetFontRotation ¶
func GFXPrimitivesSetFontRotation(rotation uint32)
func GetFramecount ¶
func GetFramecount(manager *FPSmanager) (int, bool)
func GetFramerate ¶
func GetFramerate(manager *FPSmanager) (int, bool)
func ImageFilterAbsDiff ¶
func ImageFilterAdd ¶
func ImageFilterAddByte ¶
func ImageFilterAddUint ¶
func ImageFilterBitAnd ¶
func ImageFilterBitNegation ¶
func ImageFilterBitOr ¶
func ImageFilterClipToRange ¶
func ImageFilterDiv ¶
func ImageFilterMMXdetect ¶
func ImageFilterMMXdetect() bool
func ImageFilterMMXoff ¶
func ImageFilterMMXoff()
func ImageFilterMMXon ¶
func ImageFilterMMXon()
func ImageFilterMean ¶
func ImageFilterMult ¶
func ImageFilterMultByByte ¶
func ImageFilterMultDivby2 ¶
func ImageFilterMultDivby4 ¶
func ImageFilterMultNor ¶
func ImageFilterShiftLeft ¶
func ImageFilterShiftRight ¶
func ImageFilterSub ¶
func ImageFilterSubByte ¶
func ImageFilterSubUint ¶
func InitFramerate ¶
func InitFramerate(manager *FPSmanager)
func RectangleColor ¶
func RectangleRGBA ¶
func RotateSurface90Degrees ¶
func RotoZoomSurface ¶
func RotoZoomSurfaceXY ¶
func RoundedBoxColor ¶
func RoundedBoxRGBA ¶
func RoundedRectangleColor ¶
func RoundedRectangleRGBA ¶
func SetFramerate ¶
func SetFramerate(manager *FPSmanager, rate uint32) bool
func StringColor ¶
func StringRGBA ¶
func TexturedPolygon ¶
func ThickLineColor ¶
func ThickLineRGBA ¶
func TrigonColor ¶
func TrigonRGBA ¶
func ZoomSurface ¶
Types ¶
Click to show internal directories.
Click to hide internal directories.